@@ -6,7 +6,7 @@ import logging
 from ..const import GeckoConstants
 from .observable import Observable
 
-logger = logging.getLogger(__name__)
+_LOGGER = logging.getLogger(__name__)
 
 
 class GeckoStructAccessor(Observable):
@@ -59,6 +59,9 @@ class GeckoStructAccessor(Observable):
 
         self.read_write = rw
 
+    def set_read_write(self, mode):
+        self.read_write = mode
+
     def status_block_changed(self, offset, len, previous):
         # Does the notified range intersect us, if not then we don't care!
         intersection_start = max(offset, self.pos)
@@ -66,15 +69,6 @@ class GeckoStructAccessor(Observable):
         if intersection_end - intersection_start <= 0:
             return
 
-        logger.debug(
-            "Accessor %s @ %d-%d notified of change at %d-%d",
-            self.tag,
-            self.pos,
-            self.pos + self.length,
-            offset,
-            offset + len,
-        )
-
         old_value = self._get_value(previous)
         new_value = self.value
 
@@ -82,7 +76,7 @@ class GeckoStructAccessor(Observable):
         if new_value == old_value:
             return
 
-        logger.info(
+        _LOGGER.info(
             "Value for %s changed from %s to %s", self.tag, old_value, new_value
         )
 
@@ -96,30 +90,19 @@ class GeckoStructAccessor(Observable):
         data = struct.unpack(
             self.format, status_block[self.pos : self.pos + self.length]
         )[0]
-        logger.debug(
-            "Accessor %s @ %s, %s raw data = %x", self.tag, self.pos, self.type, data
-        )
         if self.bitpos is not None:
             data = (data >> self.bitpos) & self.bitmask
-            logger.debug(
-                "BitPos %s accessor %s adjusted data = %x",
-                (self.bitpos, self.bitmask),
-                self.tag,
-                data,
-            )
         return data
 
     def _get_value(self, status_block=None):
         data = self._get_raw_value(status_block)
         if self.type == GeckoConstants.SPA_PACK_STRUCT_BOOL_TYPE:
             data = data == 1
-            logger.debug("Bool accessor %s adjusted data = %s", self.tag, data)
         elif self.type == GeckoConstants.SPA_PACK_STRUCT_ENUM_TYPE:
             try:
                 data = self.items[data]
-                logger.debug("Enum accessor %s adjusted data = %s", self.tag, data)
             except IndexError:
-                logger.exception(
+                _LOGGER.exception(
                     "Enum accessor %s out-of-range for %s. Value is %s",
                     self.tag,
                     self.items,
@@ -130,17 +113,15 @@ class GeckoStructAccessor(Observable):
         return data
 
     def _set_value(self, newvalue):
-        """ Set a value in the pack structure using the initialized declaration """
+        """Set a value in the pack structure using the initialized declaration"""
         if self.read_write is None:
             raise Exception(
                 GeckoConstants.EXCEPTION_MESSAGE_NOT_WRITABLE.format(self.tag)
             )
 
         if self.type == GeckoConstants.SPA_PACK_STRUCT_ENUM_TYPE:
-            logger.debug("Enum accessor %s adjusted from %s", self.tag, newvalue)
             newvalue = self.items.index(newvalue)
         elif self.type == GeckoConstants.SPA_PACK_STRUCT_TIME_TYPE:
-            logger.debug(f"Time accessor {self.tag} adjusted from {newvalue}")
             bits = newvalue.split(":")
             newvalue = (int(bits[0]) * 256) + (int(bits[1]) % 256)
         elif self.type == GeckoConstants.SPA_PACK_STRUCT_BYTE_TYPE and isinstance(
@@ -161,17 +142,11 @@ class GeckoStructAccessor(Observable):
             self.format, self.struct.status_block[self.pos : self.pos + self.length]
         )[0]
         if self.bitpos is not None:
-            logger.debug(
-                "Bitpos %s accessor %s adjusted from %s",
-                (self.bitpos, self.bitmask),
-                self.tag,
-                newvalue,
-            )
             newvalue = (existing & ~(self.bitmask << self.bitpos)) | (
                 (newvalue & self.bitmask) << self.bitpos
             )
 
-        logger.debug(
+        _LOGGER.debug(
             "Accessor %s @ %s, %s setting value to %s, existing value was %s. "
             "Length is %d",
             self.tag,
@@ -187,7 +162,7 @@ class GeckoStructAccessor(Observable):
 
     @property
     def value(self):
-        """ Get a value from the pack structure using the initialized declaration """
+        """Get a value from the pack structure using the initialized declaration"""
         return self._get_value()
 
     @property
@@ -198,9 +173,57 @@ class GeckoStructAccessor(Observable):
 
     @value.setter
     def value(self, newvalue):
-        """ Set a value in the pack structure using the initialized declaration """
+        """Set a value in the pack structure using the initialized declaration"""
         self._set_value(newvalue)
 
+    async def async_set_value(self, newvalue):
+        """Set a value in the pack structure using the initialized declaration"""
+        if self.read_write is None:
+            raise Exception(
+                GeckoConstants.EXCEPTION_MESSAGE_NOT_WRITABLE.format(self.tag)
+            )
+
+        if self.type == GeckoConstants.SPA_PACK_STRUCT_ENUM_TYPE:
+            newvalue = self.items.index(newvalue)
+        elif self.type == GeckoConstants.SPA_PACK_STRUCT_TIME_TYPE:
+            bits = newvalue.split(":")
+            newvalue = (int(bits[0]) * 256) + (int(bits[1]) % 256)
+        elif self.type == GeckoConstants.SPA_PACK_STRUCT_BYTE_TYPE and isinstance(
+            newvalue, str
+        ):
+            newvalue = int(newvalue)
+        elif self.type == GeckoConstants.SPA_PACK_STRUCT_WORD_TYPE and isinstance(
+            newvalue, str
+        ):
+            newvalue = int(newvalue)
+        elif self.type == GeckoConstants.SPA_PACK_STRUCT_BOOL_TYPE and isinstance(
+            newvalue, str
+        ):
+            newvalue = newvalue.lower() == "true"
+
+        # If it is a bitpos, then mask it with the existing value
+        existing = struct.unpack(
+            self.format, self.struct.status_block[self.pos : self.pos + self.length]
+        )[0]
+        if self.bitpos is not None:
+            newvalue = (existing & ~(self.bitmask << self.bitpos)) | (
+                (newvalue & self.bitmask) << self.bitpos
+            )
+
+        _LOGGER.debug(
+            "Accessor %s @ %s, %s setting value to %s, existing value was %s. "
+            "Length is %d",
+            self.tag,
+            self.pos,
+            self.type,
+            newvalue,
+            existing,
+            self.length,
+        )
+
+        # We can't handle this here, we must delegate via the structure
+        await self.struct.async_set_value(self.pos, self.length, newvalue)
+
     def __repr__(self):
         return f"{self.tag!r}: {self.value!r}"
 
@@ -235,7 +258,7 @@ class GeckoTempStructAccessor(GeckoWordStructAccessor):
     from freezing are handled"""
 
     def _get_value(self, status_block=None):
-        """ Get the temperature """
+        """Get the temperature"""
         # Internally, temp is in farenheight tenths, offset from freezing point
         temp = super()._get_value(status_block)
         units = self.struct.accessors[GeckoConstants.KEY_TEMP_UNITS].value
@@ -246,10 +269,19 @@ class GeckoTempStructAccessor(GeckoWordStructAccessor):
         return temp
 
     def _set_value(self, temp):
-        """ Set the temperature """
+        """Set the temperature"""
         units = self.struct.accessors[GeckoConstants.KEY_TEMP_UNITS].value
         if units == "C":
             temp = float(temp) * 18.0
         else:
             temp = (float(temp) * 10.0) - 320
         super()._set_value(int(temp))
+
+    async def async_set_value(self, temp):
+        """Set the temperature"""
+        units = self.struct.accessors[GeckoConstants.KEY_TEMP_UNITS].value
+        if units == "C":
+            temp = float(temp) * 18.0
+        else:
+            temp = (float(temp) * 10.0) - 320
+        await super().async_set_value(int(temp))
