@@ -2,6 +2,8 @@
 
 import asyncio
 import logging
+
+from geckolib.const import GeckoConstants
 from ..udp_socket import GeckoUdpProtocolHandler
 
 
@@ -26,7 +28,7 @@ class GeckoUnhandledProtocolHandler(GeckoUdpProtocolHandler):
                 # First time we see this, we mark the queue
                 protocol.queue.mark()
                 # Allow the rest of the tasks to operate
-                await asyncio.sleep(0)
+                await asyncio.sleep(GeckoConstants.ASYNCIO_SLEEP_TIMEOUT_FOR_YIELD)
                 # If we get here then no one processed the datagram
                 # so we can remove it and moan about it
                 if protocol.queue.is_marked:
@@ -35,4 +37,4 @@ class GeckoUnhandledProtocolHandler(GeckoUdpProtocolHandler):
                     _LOGGER.warning(
                         "No handler for %s from %s found, message ignored", data, sender
                     )
-            await asyncio.sleep(0)
+            await asyncio.sleep(GeckoConstants.ASYNCIO_SLEEP_TIMEOUT_FOR_YIELD)
